@@ -8,19 +8,19 @@ import datetime
 import inspect
 import json
 import logging
-import numpy
 import os
-import scipy
 import typing
 import warnings
 from typing import Union
 
+import numpy
+import scipy
+
 from . import utils
-from . utils import pm
+from .utils import pm
 
-
-__version__ = '6.5.2'
-_log = logging.getLogger('calibr8')
+__version__ = "6.5.3"
+_log = logging.getLogger("calibr8")
 
 
 class InferenceResult:
@@ -29,6 +29,7 @@ class InferenceResult:
 
 class ContinuousInference(InferenceResult):
     """Describes properties common for inference with continuous independent variables."""
+
     def __init__(
         self,
         eti_x: numpy.ndarray,
@@ -38,7 +39,7 @@ class ContinuousInference(InferenceResult):
         hdi_pdf: numpy.ndarray,
         hdi_prob: float,
     ) -> None:
-        """ The result of a numeric infer_independent operation.
+        """The result of a numeric infer_independent operation.
 
         Parameters
         ----------
@@ -74,22 +75,22 @@ class ContinuousInference(InferenceResult):
 
     @property
     def eti_lower(self) -> Union[float, numpy.ndarray]:
-        """ Lower bound of the ETI. This is the first value in `eti_x`. """
+        """Lower bound of the ETI. This is the first value in `eti_x`."""
         return self._eti_x[..., 0]
 
     @property
     def eti_upper(self) -> Union[float, numpy.ndarray]:
-        """ Upper bound of the ETI. This is the last value in `eti_x`. """
+        """Upper bound of the ETI. This is the last value in `eti_x`."""
         return self._eti_x[..., -1]
 
     @property
     def eti_width(self) -> Union[float, numpy.ndarray]:
-        """ Width of the ETI. """
+        """Width of the ETI."""
         return self.eti_upper - self.eti_lower
 
     @property
     def eti_prob(self) -> float:
-        """ Probability mass of the given equal tailed interval. """
+        """Probability mass of the given equal tailed interval."""
         return self._eti_prob
 
     @property
@@ -104,33 +105,34 @@ class ContinuousInference(InferenceResult):
 
     @property
     def hdi_lower(self) -> Union[float, numpy.ndarray]:
-        """ Lower bound of the HDI. This is the first value in `hdi_x`. """
+        """Lower bound of the HDI. This is the first value in `hdi_x`."""
         return self._hdi_x[..., 0]
 
     @property
     def hdi_upper(self) -> Union[float, numpy.ndarray]:
-        """ Upper bound of the HDI. This is the last value in `hdi_x`. """
+        """Upper bound of the HDI. This is the last value in `hdi_x`."""
         return self._hdi_x[..., -1]
 
     @property
     def hdi_width(self) -> Union[float, numpy.ndarray]:
-        """ Width of the HDI. """
+        """Width of the HDI."""
         return self.hdi_upper - self.hdi_lower
 
     @property
     def hdi_prob(self) -> float:
-        """ Probability mass of the given highest density interval. """
+        """Probability mass of the given highest density interval."""
         return self._hdi_prob
 
 
 class ContinuousUnivariateInference(ContinuousInference):
-    """ The result of a numeric infer_independent operation with a univariate model. """
+    """The result of a numeric infer_independent operation with a univariate model."""
+
     def __init__(
         self,
         median: float,
         **kwargs,
     ) -> None:
-        """ The result of a numeric infer_independent operation.
+        """The result of a numeric infer_independent operation.
 
         Parameters
         ----------
@@ -139,9 +141,14 @@ class ContinuousUnivariateInference(ContinuousInference):
         **kwargs : dict
             Forwarded to InferenceResult base constructor.
         """
-        self.median = median
+        self._median = median
         super().__init__(**kwargs)
 
+    @property
+    def median(self) -> float:
+        """Median of the posterior distribution. 50 % of the probability mass on either side."""
+        return self._median
+
     def __repr__(self) -> str:
         result = (
             str(type(self))
@@ -159,15 +166,11 @@ def _interval_prob(x_cdf: numpy.ndarray, cdf: numpy.ndarray, a: float, b: float)
     """Calculates the probability in the interval [a, b]."""
     ia = numpy.argmin(numpy.abs(x_cdf - a))
     ib = numpy.argmin(numpy.abs(x_cdf - b))
-    return (cdf[ib] - cdf[ia])
+    return cdf[ib] - cdf[ia]
 
 
-def _get_eti(
-    x_cdf: numpy.ndarray,
-    cdf: numpy.ndarray,
-    ci_prob: float
-) -> typing.Tuple[float, float]:
-    """ Find the equal tailed interval (ETI) corresponding to a certain credible interval probability level.
+def _get_eti(x_cdf: numpy.ndarray, cdf: numpy.ndarray, ci_prob: float) -> typing.Tuple[float, float]:
+    """Find the equal tailed interval (ETI) corresponding to a certain credible interval probability level.
 
     Parameters
     ----------
@@ -199,9 +202,9 @@ def _get_hdi(
     guess_lower: float,
     guess_upper: float,
     *,
-    history: typing.Optional[typing.DefaultDict[str, typing.List]]=None
+    history: typing.Optional[typing.DefaultDict[str, typing.List]] = None,
 ) -> typing.Tuple[float, float]:
-    """ Find the highest density interval (HDI) corresponding to a certain credible interval probability level.
+    """Find the highest density interval (HDI) corresponding to a certain credible interval probability level.
 
     Parameters
     ----------
@@ -226,6 +229,7 @@ def _get_hdi(
     hdi_upper : float
         Upper bound of the HDI
     """
+
     def hdi_objective(x):
         a, d = x
         b = a + d
@@ -265,7 +269,7 @@ def _get_hdi(
         # parametrize as b=a+d
         x0=initial_guess,
         xtol=numpy.ptp(x_cdf) / len(x_cdf),
-        disp=False
+        disp=False,
     )
     hdi_lower, hdi_width = fit
     hdi_upper = hdi_lower + hdi_width
@@ -277,6 +281,7 @@ class DistributionMixin:
     to a SciPy distribution and its parameters, and optionally also to
     a PyMC distribution and its parameters.
     """
+
     scipy_dist = None
     pymc_dist = None
 
@@ -304,10 +309,10 @@ class CalibrationModel(DistributionMixin):
 
     def __init__(
         self,
-        independent_key:str,
-        dependent_key:str,
+        independent_key: str,
+        dependent_key: str,
         *,
-        theta_names:typing.Tuple[str],
+        theta_names: typing.Tuple[str],
         ndim: int,
     ):
         """Creates a CalibrationModel object.
@@ -329,15 +334,17 @@ class CalibrationModel(DistributionMixin):
                 "\nAdd a noise model mixin to your class definition. For example:"
                 "\n`class MyModel(CalibrationModel, LaplaceNoise)`",
                 DeprecationWarning,
-                stacklevel=2
+                stacklevel=2,
             )
         # make sure that the inheriting type has no required constructor (kw)args
-        args, varargs, varkw, defaults, kwonlyargs, kwonlydefaults, annotations = inspect.getfullargspec(type(self).__init__)
+        args, varargs, varkw, defaults, kwonlyargs, kwonlydefaults, annotations = inspect.getfullargspec(
+            type(self).__init__
+        )
         n_defaults = 0 if not defaults else len(defaults)
         n_kwonlyargs = 0 if not kwonlyargs else len(kwonlyargs)
         n_kwonlydefaults = 0 if not kwonlydefaults else len(kwonlydefaults)
         if (len(args) - 1 > n_defaults) or (n_kwonlyargs > n_kwonlydefaults):
-            raise TypeError('The constructor must not have any required (kw)arguments.')
+            raise TypeError("The constructor must not have any required (kw)arguments.")
 
         # underlying private attributes
         self.__theta_timestamp = None
@@ -351,14 +358,13 @@ class CalibrationModel(DistributionMixin):
         self.theta_bounds = None
         self.theta_guess = None
         self.theta_fitted = None
-        self.cal_independent:numpy.ndarray = None
-        self.cal_dependent:numpy.ndarray = None
+        self.cal_independent: numpy.ndarray = None
+        self.cal_dependent: numpy.ndarray = None
         super().__init__()
 
     @property
     def theta_fitted(self) -> typing.Optional[typing.Tuple[float]]:
-        """ The parameter vector that describes the fitted model.
-        """
+        """The parameter vector that describes the fitted model."""
         return self.__theta_fitted
 
     @theta_fitted.setter
@@ -370,19 +376,20 @@ class CalibrationModel(DistributionMixin):
                     f"does not match the number of parameter names ({len(self.theta_names)})."
                 )
             self.__theta_fitted = tuple(value)
-            self.__theta_timestamp = datetime.datetime.now().astimezone(datetime.timezone.utc).replace(microsecond=0)
+            self.__theta_timestamp = (
+                datetime.datetime.now().astimezone(datetime.timezone.utc).replace(microsecond=0)
+            )
         else:
             self.__theta_fitted = None
             self.__theta_timestamp = None
 
     @property
     def theta_timestamp(self) -> typing.Optional[datetime.datetime]:
-        """ The timestamp when `theta_fitted` was set.
-        """
+        """The timestamp when `theta_fitted` was set."""
         return self.__theta_timestamp
 
     def predict_dependent(self, x, *, theta=None):
-        """Predicts the parameters of a probability distribution which characterises 
+        """Predicts the parameters of a probability distribution which characterises
            the dependent variable given values of the independent variable.
 
         Parameters
@@ -398,8 +405,10 @@ class CalibrationModel(DistributionMixin):
         parameters : array-like
             parameters characterizing the dependent variable distribution for given [x]
         """
-        raise NotImplementedError('The predict_dependent function should be implemented by the inheriting class.')
-    
+        raise NotImplementedError(
+            "The predict_dependent function should be implemented by the inheriting class."
+        )
+
     def predict_independent(self, y, *, theta=None):
         """Predict the independent variable using the inverse trend model.
 
@@ -416,11 +425,13 @@ class CalibrationModel(DistributionMixin):
         x : array-like
             predicted independent values given the observations
         """
-        raise NotImplementedError('The predict_independent function should be implemented by the inheriting class.')
+        raise NotImplementedError(
+            "The predict_independent function should be implemented by the inheriting class."
+        )
 
     def infer_independent(
         self,
-        y:Union[int,float,numpy.ndarray],
+        y: Union[int, float, numpy.ndarray],
         *,
         lower,
         upper,
@@ -442,20 +453,22 @@ class CalibrationModel(DistributionMixin):
         posterior : InferenceResult
             Result of the independent variable inference.
         """
-        raise NotImplementedError(f"This calibration model does not implement an .infer_independent() method.")
+        raise NotImplementedError(
+            f"This calibration model does not implement an .infer_independent() method."
+        )
 
     def loglikelihood(
         self,
         *,
         y,
         x,
-        name: str=None,
-        replicate_id: str=None,
-        dependent_key: str=None,
+        name: str = None,
+        replicate_id: str = None,
+        dependent_key: str = None,
         theta=None,
-        **dist_kwargs
+        **dist_kwargs,
     ):
-        """ Loglikelihood of observation (dependent variable) given the independent variable.
+        """Loglikelihood of observation (dependent variable) given the independent variable.
 
         If both x and y are 1D-vectors, they must have the same length and the likelihood will be evaluated elementwise.
 
@@ -490,17 +503,15 @@ class CalibrationModel(DistributionMixin):
         """
         if theta is None:
             if self.theta_fitted is None:
-                raise Exception('No parameter vector was provided and the model is not fitted with data yet.')
+                raise Exception("No parameter vector was provided and the model is not fitted with data yet.")
             theta = self.theta_fitted
 
         if not isinstance(x, (list, numpy.ndarray, float, int)) and not utils.istensor(x):
             raise ValueError(
-                f'Input x must be a scalar, TensorVariable or an array-like object, but not {type(x)}'
+                f"Input x must be a scalar, TensorVariable or an array-like object, but not {type(x)}"
             )
         if not isinstance(y, (list, numpy.ndarray, float, int)) and not utils.istensor(x):
-            raise ValueError(
-                f'Input y must be a scalar or an array-like object, but not {type(y)}'
-            )
+            raise ValueError(f"Input y must be a scalar or an array-like object, but not {type(y)}")
 
         params = self.predict_dependent(x, theta=theta)
         if utils.istensor(x) or utils.istensor(theta):
@@ -508,22 +519,14 @@ class CalibrationModel(DistributionMixin):
                 if replicate_id and dependent_key:
                     warnings.warn(
                         "The `replicate_id` and `dependent_key` parameters are deprecated. Use `name` instead.",
-                        DeprecationWarning
+                        DeprecationWarning,
                     )
-                    name = f'{replicate_id}.{dependent_key}'
+                    name = f"{replicate_id}.{dependent_key}"
                 if not name:
                     raise ValueError("A `name` must be specified for the PyMC likelihood.")
-                rv = self.pymc_dist(
-                    name,
-                    **self.to_pymc(*params),
-                    observed=y,
-                    **dist_kwargs or {}
-                )
+                rv = self.pymc_dist(name, **self.to_pymc(*params), observed=y, **dist_kwargs or {})
             else:
-                rv = self.pymc_dist.dist(
-                    **self.to_pymc(*params),
-                    **dist_kwargs or {}
-                )
+                rv = self.pymc_dist.dist(**self.to_pymc(*params), **dist_kwargs or {})
             # The API to get log-likelihood tensors differs between PyMC versions
             if pm.__version__[0] == "3":
                 if isinstance(rv, pm.model.ObservedRV):
@@ -542,8 +545,8 @@ class CalibrationModel(DistributionMixin):
                 raise NotImplementedError("No logpdf or logpmf methods found on {self.scipy_dist}.")
             return logp(y, **self.to_scipy(*params)).sum(axis=-1)
 
-    def likelihood(self, *, y, x, theta=None, scan_x: bool=False):
-        """ Likelihood of observation (dependent variable) given the independent variable.
+    def likelihood(self, *, y, x, theta=None, scan_x: bool = False):
+        """Likelihood of observation (dependent variable) given the independent variable.
 
         Relies on the `loglikelihood` method.
 
@@ -572,15 +575,12 @@ class CalibrationModel(DistributionMixin):
                     raise ValueError("The underlying model does not seem to implement broadcasting.")
                 return result
             except:
-                return numpy.exp([
-                    self.loglikelihood(y=y, x=xi, theta=theta)
-                    for xi in x
-                ])
+                return numpy.exp([self.loglikelihood(y=y, x=xi, theta=theta) for xi in x])
         return numpy.exp(self.loglikelihood(y=y, x=x, theta=theta))
 
     def objective(self, independent, dependent, minimize=True) -> typing.Callable:
         """Creates an objective function for fitting to data.
-        
+
         Parameters
         ----------
         independent : array-like
@@ -589,19 +589,21 @@ class CalibrationModel(DistributionMixin):
             observations of dependent variable
         minimize : bool
             switches between creation of a minimization (True) or maximization (False) objective function
-        
+
         Returns
         -------
         objective : callable
             takes a numeric or symbolic parameter vector and returns the
             (negative) log-likelihood
         """
+
         def objective(x):
             L = self.loglikelihood(x=independent, y=dependent, theta=x)
             if minimize:
                 return -L
             else:
                 return L
+
         return objective
 
     def save(self, filepath: os.PathLike):
@@ -614,7 +616,7 @@ class CalibrationModel(DistributionMixin):
         """
         data = dict(
             calibr8_version=__version__,
-            model_type='.'.join([self.__module__, self.__class__.__qualname__]),
+            model_type=".".join([self.__module__, self.__class__.__qualname__]),
             theta_names=tuple(self.theta_names),
             theta_bounds=tuple(self.theta_bounds),
             theta_guess=tuple(self.theta_guess),
@@ -625,7 +627,7 @@ class CalibrationModel(DistributionMixin):
             cal_independent=self.cal_independent.tolist() if self.cal_independent is not None else None,
             cal_dependent=self.cal_dependent.tolist() if self.cal_dependent is not None else None,
         )
-        with open(filepath, 'w') as jfile:
+        with open(filepath, "w") as jfile:
             json.dump(data, jfile, indent=4)
         return
 
@@ -650,34 +652,36 @@ class CalibrationModel(DistributionMixin):
         calibrationmodel : CalibrationModel
             the instantiated calibration model
         """
-        with open(filepath, 'r') as jfile:
+        with open(filepath, "r") as jfile:
             data = json.load(jfile)
-        
+
         # check compatibility
         try:
-            utils.assert_version_match(data['calibr8_version'], __version__)
+            utils.assert_version_match(data["calibr8_version"], __version__)
         except (utils.BuildMismatchException, utils.PatchMismatchException, utils.MinorMismatchException):
             pass
 
         # create model instance
-        cls_type = f'{cls.__module__}.{cls.__name__}'
-        json_type = data['model_type']
+        cls_type = f"{cls.__module__}.{cls.__name__}"
+        json_type = data["model_type"]
         if json_type != cls_type:
-            raise utils.CompatibilityException(f'The model type from the JSON file ({json_type}) does not match this class ({cls_type}).')
+            raise utils.CompatibilityException(
+                f"The model type from the JSON file ({json_type}) does not match this class ({cls_type})."
+            )
         obj = cls()
 
         # assign essential attributes
-        obj.independent_key = data['independent_key']
-        obj.dependent_key = data['dependent_key']
-        obj.theta_names = data['theta_names']
+        obj.independent_key = data["independent_key"]
+        obj.dependent_key = data["dependent_key"]
+        obj.theta_names = data["theta_names"]
 
         # assign additional attributes (check keys for backwards compatibility)
-        obj.theta_bounds = tuple(map(tuple, data['theta_bounds'])) if 'theta_bounds' in data else None
-        obj.theta_guess = tuple(data['theta_guess']) if 'theta_guess' in data else None
-        obj.__theta_fitted = tuple(data['theta_fitted']) if 'theta_fitted' in data else None
-        obj.__theta_timestamp = utils.parse_datetime(data.get('theta_timestamp', None))
-        obj.cal_independent = numpy.array(data['cal_independent']) if 'cal_independent' in data else None
-        obj.cal_dependent = numpy.array(data['cal_dependent']) if 'cal_dependent' in data else None
+        obj.theta_bounds = tuple(map(tuple, data["theta_bounds"])) if "theta_bounds" in data else None
+        obj.theta_guess = tuple(data["theta_guess"]) if "theta_guess" in data else None
+        obj.__theta_fitted = tuple(data["theta_fitted"]) if "theta_fitted" in data else None
+        obj.__theta_timestamp = utils.parse_datetime(data.get("theta_timestamp", None))
+        obj.cal_independent = numpy.array(data["cal_independent"]) if "cal_independent" in data else None
+        obj.cal_dependent = numpy.array(data["cal_dependent"]) if "cal_dependent" in data else None
         return obj
 
 
@@ -687,15 +691,15 @@ class ContinuousUnivariateModel(CalibrationModel):
 
     def infer_independent(
         self,
-        y:Union[int, float, numpy.ndarray],
+        y: Union[int, float, numpy.ndarray],
         *,
-        lower:float,
-        upper:float,
-        steps:int=300,
-        ci_prob:float=1,
+        lower: float,
+        upper: float,
+        steps: int = 300,
+        ci_prob: float = 1,
     ) -> ContinuousUnivariateInference:
         """Infer the posterior distribution of the independent variable given the observations of the dependent variable.
-        The calculation is done numerically by integrating the likelihood in a certain interval [upper,lower]. 
+        The calculation is done numerically by integrating the likelihood in a certain interval [upper,lower].
         This is identical to the posterior with a Uniform (lower,upper) prior.
 
         Parameters
@@ -718,7 +722,7 @@ class ContinuousUnivariateModel(CalibrationModel):
         -------
         posterior : ContinuousUnivariateInference
             Result of the numeric posterior calculation.
-        """  
+        """
         y = numpy.atleast_1d(y)
 
         likelihood_integral, _ = scipy.integrate.quad(
@@ -729,27 +733,34 @@ class ContinuousUnivariateModel(CalibrationModel):
             # 2. prior probability is 0 outside of [a,b]
             # > numerical integral is only computed in [a,b], but because of 1. and 2., it's
             #   identical to the integral over [-∞,+∞]
-            a=lower, b=upper,
+            a=lower,
+            b=upper,
         )
 
         # high resolution x-coordinates for integration
         # the first integration is just to find the peak
         x_integrate = numpy.linspace(lower, upper, 10_000)
-        area = scipy.integrate.cumtrapz(self.likelihood(x=x_integrate, y=y, scan_x=True), x_integrate, initial=0)
+        area = scipy.integrate.cumtrapz(
+            self.likelihood(x=x_integrate, y=y, scan_x=True), x_integrate, initial=0
+        )
         cdf = area / area[-1]
 
         # now we find a high-resolution CDF for (1-shrink) of the probability mass
         shrink = 0.00001
         xfrom, xto = _get_eti(x_integrate, cdf, 1 - shrink)
         x_integrate = numpy.linspace(xfrom, xto, 100_000)
-        area = scipy.integrate.cumtrapz(self.likelihood(x=x_integrate, y=y, scan_x=True), x_integrate, initial=0)
+        area = scipy.integrate.cumtrapz(
+            self.likelihood(x=x_integrate, y=y, scan_x=True), x_integrate, initial=0
+        )
         cdf = (area / area[-1]) * (1 - shrink) + shrink / 2
 
         # TODO: create a smart x-vector from the CDF with varying stepsize
 
         if ci_prob != 1:
             if not isinstance(ci_prob, (int, float)) or not (0 < ci_prob <= 1):
-                raise ValueError(f'Unexpected `ci_prob` value of {ci_prob}. Expected float in interval (0, 1].')
+                raise ValueError(
+                    f"Unexpected `ci_prob` value of {ci_prob}. Expected float in interval (0, 1]."
+                )
 
             # determine the interval bounds from the high-resolution CDF
             eti_lower, eti_upper = _get_eti(x_integrate, cdf, ci_prob)
@@ -771,22 +782,30 @@ class ContinuousUnivariateModel(CalibrationModel):
 
         return ContinuousUnivariateInference(
             median,
-            eti_x=eti_x, eti_pdf=eti_pdf, eti_prob=eti_prob,
-            hdi_x=hdi_x, hdi_pdf=hdi_pdf, hdi_prob=hdi_prob,
+            eti_x=eti_x,
+            eti_pdf=eti_pdf,
+            eti_prob=eti_prob,
+            hdi_x=hdi_x,
+            hdi_pdf=hdi_pdf,
+            hdi_prob=hdi_prob,
         )
 
 
 class ContinuousMultivariateModel(CalibrationModel):
-    def __init__(self, independent_key: str, dependent_key: str, *, theta_names: typing.Tuple[str], ndim: int):
+    def __init__(
+        self, independent_key: str, dependent_key: str, *, theta_names: typing.Tuple[str], ndim: int
+    ):
         super().__init__(independent_key, dependent_key, theta_names=theta_names, ndim=ndim)
 
-    def infer_independent(self, y: Union[int, float, numpy.ndarray], *, lower, upper) -> ContinuousMultivariateInference:
+    def infer_independent(
+        self, y: Union[int, float, numpy.ndarray], *, lower, upper
+    ) -> ContinuousMultivariateInference:
         return super().infer_independent(y, lower=lower, upper=upper)
 
 
 def logistic(x, theta):
     """4-parameter logistic model.
-        
+
     Parameters
     ----------
     x : array-like
@@ -797,7 +816,7 @@ def logistic(x, theta):
             I_y: y-value at inflection point
             Lmax: maximum value
             s: slope at the inflection point
-        
+
     Returns
     -------
     y : array-like
@@ -805,13 +824,13 @@ def logistic(x, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     x = numpy.array(x)
-    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2*s/(Lmax - I_y) * (x - I_x)))
+    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2 * s / (Lmax - I_y) * (x - I_x)))
     return y
 
 
 def inverse_logistic(y, theta):
     """Inverse 4-parameter logistic model.
-    
+
     Parameters
     ----------
     y : array-like
@@ -822,7 +841,7 @@ def inverse_logistic(y, theta):
             I_y: y-value at inflection point
             Lmax: maximum value
             s: slope at the inflection point
-    
+
     Returns
     -------
     x : array-like
@@ -830,13 +849,13 @@ def inverse_logistic(y, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     y = numpy.array(y)
-    x = I_x-((Lmax-I_y)/(2*s))*numpy.log((2*(Lmax-I_y)/(y+Lmax-2*I_y))-1)
+    x = I_x - ((Lmax - I_y) / (2 * s)) * numpy.log((2 * (Lmax - I_y) / (y + Lmax - 2 * I_y)) - 1)
     return x
 
 
 def asymmetric_logistic(x, theta):
     """5-parameter asymmetric logistic model.
-    
+
     Parameters
     ----------
     x : array-like
@@ -848,7 +867,7 @@ def asymmetric_logistic(x, theta):
             I_x: x-value at inflection point
             S: slope at the inflection point
             c: symmetry parameter (0 is symmetric)
-    
+
     Returns
     -------
     y : array-like
@@ -864,12 +883,12 @@ def asymmetric_logistic(x, theta):
 
     x = numpy.array(x)
     y = (numpy.exp(s2 * (s3 * (I_x - x) + c / s2)) + 1) ** -s1
-    return L_L + (L_U-L_L) * y
+    return L_L + (L_U - L_L) * y
 
 
 def inverse_asymmetric_logistic(y, theta):
     """Inverse 5-parameter asymmetric logistic model.
-    
+
     Parameters
     ----------
     y : array-like
@@ -881,7 +900,7 @@ def inverse_asymmetric_logistic(y, theta):
             I_x: x-value at inflection point
             S: slope at the inflection point
             c: symmetry parameter (0 is symmetric)
-    
+
     Returns
     -------
     x : array-like
@@ -890,23 +909,23 @@ def inverse_asymmetric_logistic(y, theta):
     L_L, L_U, I_x, S, c = theta[:5]
     # re-scale the inflection point slope with the interval
     s = S / (L_U - L_L)
-    
+
     # re-scale into the interval [0, 1]
     y = numpy.array(y)
     y = (y - L_L) / (L_U - L_L)
-    
+
     x0 = numpy.exp(c)
     x1 = x0 + 1
     x2 = -c
     x3 = numpy.exp(x2)
-    x4 = I_x*s*x1**x3
-    
-    return - (x1**(-x1*x3) * numpy.log( ((1/y)**x0 - 1) * numpy.exp(-x0*x4+x2-x4) ) ) / s
+    x4 = I_x * s * x1**x3
+
+    return -(x1 ** (-x1 * x3) * numpy.log(((1 / y) ** x0 - 1) * numpy.exp(-x0 * x4 + x2 - x4))) / s
 
 
 def xlog_asymmetric_logistic(x, theta):
     """5-parameter asymmetric logistic model on log10 independent value.
-    
+
     Parameters
     ----------
     x : array-like
@@ -918,7 +937,7 @@ def xlog_asymmetric_logistic(x, theta):
             log_I_x: log10(x)-value at x-logarithmic inflection point
             S: slope at the inflection point (Δy/Δlog10(x))
             c: symmetry parameter (0 is symmetric)
-    
+
     Returns
     -------
     y : array-like
@@ -931,15 +950,15 @@ def xlog_asymmetric_logistic(x, theta):
     s2 = s0 ** (s0 * s1)
     # re-scale the inflection point slope with the interval
     s3 = S / (L_U - L_L)
-    
+
     x = numpy.array(x)
     y = (numpy.exp(s2 * (s3 * (log_I_x - numpy.log10(x)) + c / s2)) + 1) ** -s1
-    return L_L + (L_U-L_L) * y
+    return L_L + (L_U - L_L) * y
 
 
 def inverse_xlog_asymmetric_logistic(y, theta):
     """Inverse 5-parameter asymmetric logistic model on log10 independent value.
-    
+
     Parameters
     ----------
     y : array-like
@@ -951,7 +970,7 @@ def inverse_xlog_asymmetric_logistic(y, theta):
             log_I_x: log10(x)-value at x-logarithmic inflection point
             S: slope at the inflection point (Δy/Δlog10(x))
             c: symmetry parameter (0 is symmetric)
-    
+
     Returns
     -------
     x : array-like
@@ -960,24 +979,24 @@ def inverse_xlog_asymmetric_logistic(y, theta):
     L_L, L_U, log_I_x, S, c = theta[:5]
     # re-scale the inflection point slope with the interval
     s = S / (L_U - L_L)
-    
+
     # re-scale into the interval [0, 1]
     y = numpy.array(y)
     y = (y - L_L) / (L_U - L_L)
-    
+
     x0 = numpy.exp(c)
     x1 = x0 + 1
     x2 = -c
     x3 = numpy.exp(x2)
     x4 = log_I_x * s * x1**x3
 
-    x_hat = - (x1**(-x1*x3) * numpy.log( ((1/y)**x0 - 1) * numpy.exp(-x0*x4+x2-x4) ) ) / s
+    x_hat = -(x1 ** (-x1 * x3) * numpy.log(((1 / y) ** x0 - 1) * numpy.exp(-x0 * x4 + x2 - x4))) / s
     return 10**x_hat
 
 
 def log_log_logistic(x, theta):
     """4-parameter log-log logistic model.
-    
+
     Parameters
     ----------
     x : array-like
@@ -988,7 +1007,7 @@ def log_log_logistic(x, theta):
             I_y: inflection point (ln(y))
             Lmax: logarithmic maximum value
             s: slope at the inflection point
-    
+
     Returns
     -------
     y : array-like
@@ -996,13 +1015,13 @@ def log_log_logistic(x, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     x = numpy.log(x)
-    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2*s/(Lmax - I_y) * (x - I_x)))
+    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2 * s / (Lmax - I_y) * (x - I_x)))
     return numpy.exp(y)
 
 
 def inverse_log_log_logistic(y, theta):
     """4-parameter log-log logistic model.
-        
+
     Parameters
     ----------
     y : array-like
@@ -1013,7 +1032,7 @@ def inverse_log_log_logistic(y, theta):
             I_y: y-value at inflection point (ln(y))
             Lmax: maximum value in log space
             s: slope at the inflection point
-    
+
     Returns
     -------
     x : array-like
@@ -1021,13 +1040,13 @@ def inverse_log_log_logistic(y, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     y = numpy.log(y)
-    x = I_x-((Lmax-I_y)/(2*s))*numpy.log((2*(Lmax-I_y)/(y+Lmax-2*I_y))-1)
+    x = I_x - ((Lmax - I_y) / (2 * s)) * numpy.log((2 * (Lmax - I_y) / (y + Lmax - 2 * I_y)) - 1)
     return numpy.exp(x)
 
 
 def xlog_logistic(x, theta):
     """4-parameter x-log logistic model.
-    
+
     Parameters
     ----------
     x : array-like
@@ -1038,7 +1057,7 @@ def xlog_logistic(x, theta):
             I_y: inflection point (y)
             Lmax: maximum value
             s: slope at the inflection point
-    
+
     Returns
     -------
     y : array-like
@@ -1046,13 +1065,13 @@ def xlog_logistic(x, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     x = numpy.log(x)
-    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2*s/(Lmax - I_y) * (x - I_x)))
+    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2 * s / (Lmax - I_y) * (x - I_x)))
     return y
 
 
 def inverse_xlog_logistic(y, theta):
     """Inverse 4-parameter x-log logistic model.
-        
+
     Parameters
     ----------
     y : array-like
@@ -1063,7 +1082,7 @@ def inverse_xlog_logistic(y, theta):
             I_y: y-value at inflection point
             Lmax: maximum value
             s: slope at the inflection point
-    
+
     Returns
     -------
     x : array-like
@@ -1071,13 +1090,13 @@ def inverse_xlog_logistic(y, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     y = numpy.array(y)
-    x = I_x-((Lmax-I_y)/(2*s))*numpy.log((2*(Lmax-I_y)/(y+Lmax-2*I_y))-1)
+    x = I_x - ((Lmax - I_y) / (2 * s)) * numpy.log((2 * (Lmax - I_y) / (y + Lmax - 2 * I_y)) - 1)
     return numpy.exp(x)
 
 
 def ylog_logistic(x, theta):
     """4-parameter y-log logistic model.
-    
+
     Parameters
     ----------
     x : array-like
@@ -1088,7 +1107,7 @@ def ylog_logistic(x, theta):
             I_y: inflection point (ln(y))
             Lmax: maximum value in log sapce
             s: slope at the inflection point
-    
+
     Returns
     -------
     y : array-like
@@ -1096,13 +1115,13 @@ def ylog_logistic(x, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     x = numpy.array(x)
-    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2*s/(Lmax - I_y) * (x - I_x)))
+    y = 2 * I_y - Lmax + (2 * (Lmax - I_y)) / (1 + numpy.exp(-2 * s / (Lmax - I_y) * (x - I_x)))
     return numpy.exp(y)
 
 
 def inverse_ylog_logistic(y, theta):
     """Inverse 4-parameter y-log logistic model.
-        
+
     Parameters
     ----------
     y : array-like
@@ -1113,7 +1132,7 @@ def inverse_ylog_logistic(y, theta):
             I_y: y-value at inflection point (ln(y))
             Lmax: maximum value in log space
             s: slope at the inflection point
-    
+
     Returns
     -------
     x : array-like
@@ -1121,7 +1140,7 @@ def inverse_ylog_logistic(y, theta):
     """
     I_x, I_y, Lmax, s = theta[:4]
     y = numpy.log(y)
-    x = I_x-((Lmax-I_y)/(2*s))*numpy.log((2*(Lmax-I_y)/(y+Lmax-2*I_y))-1)
+    x = I_x - ((Lmax - I_y) / (2 * s)) * numpy.log((2 * (Lmax - I_y) / (y + Lmax - 2 * I_y)) - 1)
     return x
 
 
@@ -1146,7 +1165,7 @@ def polynomial(x, theta):
 
 def exponential(x, theta):
     """3-parameter exponential model.
-    
+
     Parameters
     ----------
     x : array-like
@@ -1156,19 +1175,19 @@ def exponential(x, theta):
         - I: y-axis intercept
         - L: asymptotic limit
         - k: kinetic rate
-    
+
     Returns
     -------
     y : array-like
         dependent variable
     """
-    I,L,k = theta[:3]
-    return (L-I) *(1-numpy.exp(-k*x)) + I
+    I, L, k = theta[:3]
+    return (L - I) * (1 - numpy.exp(-k * x)) + I
 
 
 def inverse_exponential(y, theta):
     """Inverse of 3-parameter exponential model.
-    
+
     Parameters
     ----------
     y : array-like
@@ -1178,11 +1197,11 @@ def inverse_exponential(y, theta):
         - I: y-axis intercept
         - L: asymptotic limit
         - k: kinetic rate
-    
+
     Returns
     -------
     x : array-like
         independent variable
     """
-    I,L,k = theta[:3]
-    return -1/k * numpy.log(1-(y-I)/(L-I))
+    I, L, k = theta[:3]
+    return -1 / k * numpy.log(1 - (y - I) / (L - I))
